@@ -1,7 +1,7 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 6/18/2009	ELL
 // Revised: 2/8/2012	ELL
@@ -9,21 +9,42 @@
 	
 	
 	include ("check_session.php");
+	
+	if ($access_level != "admin")
+		exit;
 		
 	$password = $_REQUEST['password'];
 	
+	if (isset($_SESSION['update_breeze_mode']))	// Check for expiration.
+	{
+		if (intval($_SESSION['update_breeze_mode']) < time())
+			unset($_SESSION['update_breeze_mode']);
+	}
+	
 ?>
+<!DOCTYPE html>
 <html>
 <head>
-<title>Breeze Website Builder</title>
+<title>Run SQL | Breeze Website Builder</title>
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
 <link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">
 
-<link rel="stylesheet" href="manager.css" type="text/css">
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
+
+<style type="text/css">
+#table_structure_upgrade_login_btn	{
+	width:100px;
+	position:inherit;
+}
+#upgrade_table_structures_heading	{	width:240px;	}
+#help_button	{	left:200px;	}
+</style>
 
 <script language="javascript" src="js/hash.js" type="text/javascript"> </script>
 
 <script language="javascript" type="text/javascript">
+	window.parent.document.title = document.title;
+	
 	function OpenHelpWindow()
 	{
 		window.open("http://breezewebsitebuilder.com/docs/cms/help.html#upgrade_db", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
@@ -49,22 +70,26 @@ function checkForEnter(e) {
 
 </head>
 
-<body onLoad="document.getElementById('password_input').focus();">
+<body <?php if ((!$password) && (!isset($_SESSION['update_breeze_mode']))) { ?>onLoad="document.getElementById('password_input').focus();"<?php } ?>>
 <?php
-	if (!$password)
+	if ((!$password) && (!isset($_SESSION['update_breeze_mode'])))
 	{
 ?>
         <form action="input_sql.php" method="post" enctype="multipart/form-data" name="formLogin" id="formLogin">
-        <p class="title" align="center">Please enter the password for the "admin" user account:</p>
+        <p class="title" align="center"><?php echo INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN; ?>:</p>
         <p align="center"><input name="password_input" id="password_input" type="password" onKeyDown="checkForEnter(event);" /></p>
         <input type="hidden" name="password" id="password" />
-        <p align="center"><input name="Submit" type="button" value="Login" onClick="SubmitLogin();" /></p>
+        <p align="center">
+        <table align="center" border="0"><tr><td>
+        <div class='button_console' id="table_structure_upgrade_login_btn" onClick="SubmitLogin();"><span class='button_console_text'><?php echo LOGIN_LOGIN_BTN; ?></span></div>
+        </td></tr></table>
+        </p>
         </form>
 <?php
 	}
 	else
 	{
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = 'admin'";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = '" . $userid . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		
@@ -114,14 +139,18 @@ function checkForEnter(e) {
 		
 		$decrypt_text = str_replace(BWB_SALT, '', $decrypt_text);
 		$password_lookup = hash('sha256', $decrypt_text);
-		if ($password_lookup == $password)
+		if (($password_lookup == $password) || (isset($_SESSION['update_breeze_mode'])))
 		{
 ?>
-    <p class="title" align="center">Ugrade Database Tables</p>
-    <form name="frmUdateSQL" method="post" action="run_sql.php">
+    
+    <table align="center" border="0"><tr><td>
+    <div class="button_heading_sub_level_1" id="upgrade_table_structures_heading">
+      <div class="button_heading_text_sub_level_1"><?php echo RUN_SQL_HEADING; ?></div><div class="button_heading_help" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
+    </td></tr></table>
+    <form name="frmUdateSQL" id="frmUdateSQL" method="post" action="run_sql_shell.php">
      <table align="center" width="80%">
      <tr>
-        <td colspan="3" align="center">
+        <td align="center">
       <label>
         <textarea name="sql_string" id="sql_string" cols="100" rows="20"></textarea>
       </label>
@@ -129,31 +158,22 @@ function checkForEnter(e) {
       </tr>
       <tr>
         <td align="center">
-      <input type="submit" name="button" id="button" value="Submit">
-        </td>
-        <td align="center">
-      <input type="button" name="Back" value="Back to Main Menu" onClick="window.location.href='main.php?mode=admin';">
-        </td>
-        <td align="center">
-        <div id="help_button_sm" onClick="OpenHelpWindow();">
-	    &nbsp;
-      	</div>
+        <div class='button_console' id="table_structure_upgrade_login_btn" onClick="document.getElementById('frmUdateSQL').submit();"><span class='button_console_text'><?php echo SUBMIT_WORD; ?></span></div>
         </td>
       </tr>
      </table>
     </form>
     <table width="80%" border="0" cellspacing="5" cellpadding="5" align="center">
       <tr>
-        <td class="small_message" align="center">Open the file named "upgrade.sql" in a text editor such as Notepad and
-        copy and paste the text into the window above.  Then click &quot;Submit&quot;.<br>
-        Note: Each SQL command must be terminated by a semicolon ( ; ). Lines beginning with ( -- ) or ( // ) will be treated as comments.</td>
+        <td class="small_message" align="center"><?php echo RUN_SQL_PASTE_SQL_MSG; ?><br>
+        <?php echo RUN_SQL_SQL_COMMAND_DELIMITERS_NOTE; ?></td>
       </tr>
     </table>
     
 <?php
 		}
 		else
-			echo "Your password has not been confirmed.   Click <a href='input_sql.php'> here </a> to re-enter your password.";
+			echo LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG . " " . CLICK_WORD . " <a href='input_sql.php'> " . HERE_WORD . " </a> " . LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG;
 	}
 ?>
 
