@@ -355,7 +355,7 @@ define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "Level II Text Sub Color")
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "Top Level Background Colo");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "Sub Level Background Colo");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "Top Level Block Border Color");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "Sub Level Block Border Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "Acta Border Color sub Level I");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "Top Item Level Border Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "Item Level Color sub limite");
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "T <br> O <br> p");
@@ -406,8 +406,8 @@ define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "Select a menu turpis.");
 ///////////////////////// Edit CSS Select /////////////////////////
 // Buttons:
 define('EDIT_CSS_SELECT_HEADING', "Edit Styles");
-define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "Copy Style Sheet in Mobile");
-define('COPY_STYLE_TO_MOBILE_NOTE', "Officium hoc enim mobile initializing genera generibus escritorio semel analogiam cum compleveris escritorio sententia statuens styli rudentis. Usu te quis creavit haec rescribere functio style mobilis ad te scribendi. Non est necesse, ut hoc munus, sed potest esse principium creandi mobile generum commodum est. Etiam ut dui creare stilo rudentis quod mobile non simili stilo Style rudentis mobile per defaltam.");
+define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "Inter exemplum Penicullus Ovis Desktop / Mobile / Touchscreen");
+define('COPY_STYLE_TO_MOBILE_NOTE', "Desktop pro munere initializing mobile vel ad similitudinem stili Tag desktop diversa genera mobile aliquando Tag erigerent expleto rudentis aliqua styli desktop mobilis Tag felis. Hoc munus in usus overwrite quis creavit te ad locum desideratum desktop, sive mobile nervis imitati sunt touchscreen style es. Hoc munus non est necessarium, sed potest esse habilis non est ita, post initium dicendi generibus a mobili pro partum vestri desktop website, vel e converso. Item, vos potest creare seu mobilis touchscreen style rudentis style-type: non similiter mobile per default Style rudentis.");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "Tu cave ne imitari velis");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_2_MSG', "? Omnes styles in");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_3_MSG', "overwritten erit. (Hoc non potest non esse quod factum est.)");
@@ -1506,7 +1506,7 @@ define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "Nos mos iam load de causa dice
 define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Et nunc inhaero vestri caput capitis in vertice ad pasco fenestra.");
 define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Effingo ... fonts");
 define('MANAGE_MENUS_COPY_MENU_BTN', "exemplum Menu");
-define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Menu Item exemplum Desktop ut mobile");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Item exemplum Menu");
 define('MANAGE_MENUS_CREATE_NEW', "novum Menu");
 define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Esne certus vos volo ut effingo quod");
 define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "in menu");
@@ -1514,4 +1514,27 @@ define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "menu?");
 define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "in menu items");
 define('TO_1ST_CAP_WORD', "Ad");
 define('FROM_WORD', "Ex");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_HEADING', "Menu Item exemplum ut Desktop, mobile sive Touchscreen Menu");
+define('MANAGE_MENUS_DESTINATION_TYPE', "Destination Type");
+define('TOUCHSCREEN_WORD', "touchscreen");
+define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "Tuum style sheet est prima ad naturalia.");
+define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "Sed error fuit exscribend testatem tuum style sheet.");
+define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "fons Type");
+define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "Destination genus non lectus. Select a forum quod genus iterum conare.");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "Level II Acta sub Border Color");
+define('MANAGE_FONTS_INSTRUCTIONS_1', "Nota: Mutationes memoriae non nisi click");
+define('MANAGE_FONTS_INSTRUCTIONS_2', "clicking");
+define('MANAGE_FONTS_INSTRUCTIONS_3', "mos partum a novus exemplum tuum tecum font parametri. Quod si tibi tantum in mutantur font Maecenas lacus pede, click");
+define('MANAGE_FONTS_INSTRUCTIONS_4', "fonte primo ad eam delere. Tantum lima typus of III, OTF, WOFF, WOFF2, SVG &amp; EOT non licet.");
+define('MANAGE_FONTS_FONT_SAVED_MSG', "Et font quae servatae sunt.");
+define('MANAGE_FONTS_ERROR_SAVING_FONT_ERR', "Salutari fonte fuit error.");
+define('MANAGE_FONTS_ADD_BEFORE_SAVE_NEW_MSG', "Tu nova servatae sunt, non quae font. Addito fonte novo nisi commodo ante.");
+define('MANAGE_FONTS_FONT_UPLOADED_MSG', "Font file uploaded tuum est.");
+define('MANAGE_FONTS_FONT_UPLOAD_ERR', "Fuit error conanti ad upload in fonte levet.");
+define('MANAGE_FONTS_FONT_UPLOAD_CANCEL_MSG', "Et donavit at eget est a nexu omissa pasco aut usor.");
+define('MANAGE_FONTS_NO_FONT_ERR', "Quod &#39;Font&#39; necesse non esse blank.");
+define('MANAGE_FONTS_NO_UPLOAD_ERR', "Si &#39;Index&#39; sedatus est, a upload lima ut must be delecti ex vestri computer.");
+define('MANAGE_FONTS_NO_URL_ERR', "Si URL cohibetur, URL Neque vestis.");
+define('RUN_SQL_BACK_TO_EDIT_CSS_SELECT', "Curre ad SQL");
+define('RUN_SQL_QUERY_SUCCESS_MSG', "Quaero feliciter confecto");
 ?>
\ No newline at end of file
