@@ -355,7 +355,7 @@ define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "分2级文本颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "顶级背景颜色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "分等级背景颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "最顶层的方块边框颜色");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "分级别阻止边框颜色");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "子级别1块边框颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "顶层项目边框颜色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "分层次的项目边框颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "ŧ <br> Ø <br> p");
@@ -406,8 +406,8 @@ define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "请选择一个风格的菜单。
 ///////////////////////// Edit CSS Select /////////////////////////
 // Buttons:
 define('EDIT_CSS_SELECT_HEADING', "编辑样式");
-define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "复制样式表到手机");
-define('COPY_STYLE_TO_MOBILE_NOTE', "此功能是，一旦你已经完成了桌面视图设置您的样式表与类似的桌面风格初始化手机的风格。这个功能的使用将覆盖您为要复制到移动样式表创建的任何样式。这是没有必要使用此功能，但它可以很方便的为起点，创建您的手机款式。此外，您还可以创建为默认情况下不具有相似的手机样式表样式表的移动样式表。");
+define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "在桌面/手机/触摸屏之间复制样式表");
+define('COPY_STYLE_TO_MOBILE_NOTE', "此功能用于在桌面，手机或触摸屏视图中的任意一个完成设置样式表后，使用类似的桌面，移动或触摸屏样式来初始化桌面，移动或触摸屏样式。使用此功能将覆盖您为要复制到的目标桌面，移动设备或触摸屏样式表创建的任何样式。没有必要使用这个功能，但它可以方便地作为创建您的移动样式后，创建一个桌面网站，反之亦然。此外，您可以为默认情况下没有类似移动样式表的样式表创建移动或触摸屏样式表。");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "你确定要复制");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_2_MSG', "？所有的样式");
 define('COPY_STYLE_TO_MOBILE_CONFIRM_3_MSG', "将被覆盖。 （这不能被撤消。）");
@@ -1506,7 +1506,7 @@ define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "现在，我们将使用设置
 define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "您的标题现在将粘贴到浏览器窗口的顶部。");
 define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "复制字体...");
 define('MANAGE_MENUS_COPY_MENU_BTN', "复制菜单");
-define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "将桌面菜单项复制到手机");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "复制菜单项目");
 define('MANAGE_MENUS_CREATE_NEW', "新菜单");
 define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "你确定你想复制这个");
 define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "菜单");
@@ -1514,4 +1514,27 @@ define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "菜单？");
 define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "菜单项");
 define('TO_1ST_CAP_WORD', "至");
 define('FROM_WORD', "从");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_HEADING', "将菜单项复制到桌面，手机或触摸屏菜单");
+define('MANAGE_MENUS_DESTINATION_TYPE', "目标类型");
+define('TOUCHSCREEN_WORD', "触摸屏");
+define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "您的样式表已被复制。");
+define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "复制样式表时出错。");
+define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "来源类型");
+define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "目的地类型未被选中。请选择目的地类型，然后重试。");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "子级别2块边框颜色");
+define('MANAGE_FONTS_INSTRUCTIONS_1', "注意：除非您点击，否则更改不会被记录");
+define('MANAGE_FONTS_INSTRUCTIONS_2', "点击");
+define('MANAGE_FONTS_INSTRUCTIONS_3', "将使用新参数创建您的字体的副本。如果您只是更改字体参数，请单击");
+define('MANAGE_FONTS_INSTRUCTIONS_4', "在原始字体旁边删除它。只允许TTF，OTF，WOFF，WOFF2，SVG和EOT的文件类型。");
+define('MANAGE_FONTS_FONT_SAVED_MSG', "字体已保存。");
+define('MANAGE_FONTS_ERROR_SAVING_FONT_ERR', "保存字体时出错。");
+define('MANAGE_FONTS_ADD_BEFORE_SAVE_NEW_MSG', "您有一个尚未保存的新字体。请在添加新字体之前保存该字体。");
+define('MANAGE_FONTS_FONT_UPLOADED_MSG', "您的字体文件已上传。");
+define('MANAGE_FONTS_FONT_UPLOAD_ERR', "试图上传字体时出错。");
+define('MANAGE_FONTS_FONT_UPLOAD_CANCEL_MSG', "上传已被用户取消或浏览器断开连接。");
+define('MANAGE_FONTS_NO_FONT_ERR', "&#39;字体&#39;不能为空。");
+define('MANAGE_FONTS_NO_UPLOAD_ERR', "如果选择“上传”，则必须从您的计算机中选择要上传的文件。");
+define('MANAGE_FONTS_NO_URL_ERR', "如果选中“网址”，则“网址”不能为空。");
+define('RUN_SQL_BACK_TO_EDIT_CSS_SELECT', "返回运行SQL");
+define('RUN_SQL_QUERY_SUCCESS_MSG', "查询成功完成");
 ?>
\ No newline at end of file
