@@ -608,7 +608,7 @@ define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "分2級文本顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "頂級背景顏色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "分等級背景顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "最頂層的方塊邊框顏色");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "分級別阻止邊框顏色");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "子級別1塊邊框顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "頂層項目邊框顏色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "分層次的項目邊框顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "ŧ <br> Ø <br> p");
@@ -694,9 +694,9 @@ define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "請選擇一個風格的菜單。
 
 define('EDIT_CSS_SELECT_HEADING', "編輯樣式");
 
-define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "複製樣式表到手機");
+define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "在桌面/手機/觸摸屏之間複製樣式表");
 
-define('COPY_STYLE_TO_MOBILE_NOTE', "此功能是，一旦你已經完成了桌面視圖設置您的樣式表與類似的桌面風格初始化手機的風格。這個功能的使用將覆蓋您為要複製到移動樣式表創建的任何樣式。這是沒有必要使用此功能，但它可以很方便的為起點，創建您的手機款式。此外，您還可以創建為默認情況下不具有相似的手機樣式表樣式表的移動樣式表。");
+define('COPY_STYLE_TO_MOBILE_NOTE', "此功能用於在桌面，手機或觸摸屏視圖中的任意一個完成設置樣式表後，使用類似的桌面，移動或觸摸屏樣式來初始化桌面，移動或觸摸屏樣式。使用此功能將覆蓋您為要復製到的目標桌面，移動設備或觸摸屏樣式表創建的任何樣式。沒有必要使用這個功能，但它可以作為創建您的移動樣式後的樣式桌面網站或反之亦然的起點。此外，您可以為默認情況下沒有類似移動樣式表的樣式表創建移動或觸摸屏樣式表。");
 
 define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "你確定要複製");
 
@@ -2771,7 +2771,7 @@ define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "現在，我們將使用設置
 define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "您的標題現在將粘貼到瀏覽器窗口的頂部。");
 define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "複製字體...");
 define('MANAGE_MENUS_COPY_MENU_BTN', "複製菜單");
-define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "將桌面菜單項複製到手機");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "複製菜單項目");
 define('MANAGE_MENUS_CREATE_NEW', "新菜單");
 define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "你確定你想複製這個");
 define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "菜單");
@@ -2779,4 +2779,27 @@ define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "菜單？");
 define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "菜單項");
 define('TO_1ST_CAP_WORD', "至");
 define('FROM_WORD', "從");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_HEADING', "將菜單項複製到桌面，手機或觸摸屏菜單");
+define('MANAGE_MENUS_DESTINATION_TYPE', "目標類型");
+define('TOUCHSCREEN_WORD', "觸摸屏");
+define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "您的樣式表已被複製。");
+define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "複製樣式表時出錯。");
+define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "來源類型");
+define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "目的地類型未被選中。請選擇目的地類型，然後重試。");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "子級別2塊邊框顏色");
+define('MANAGE_FONTS_INSTRUCTIONS_1', "注意：除非您點擊，否則更改不會被記錄");
+define('MANAGE_FONTS_INSTRUCTIONS_2', "點擊");
+define('MANAGE_FONTS_INSTRUCTIONS_3', "將使用新參數創建您的字體的副本。如果您只是更改字體參數，請單擊");
+define('MANAGE_FONTS_INSTRUCTIONS_4', "在原始字體旁邊刪除它。只允許TTF，OTF，WOFF，WOFF2，SVG和EOT的文件類型。");
+define('MANAGE_FONTS_FONT_SAVED_MSG', "字體已保存。");
+define('MANAGE_FONTS_ERROR_SAVING_FONT_ERR', "保存字體時出錯。");
+define('MANAGE_FONTS_ADD_BEFORE_SAVE_NEW_MSG', "您有一個尚未保存的新字體。請在添加新字體之前保存該字體。");
+define('MANAGE_FONTS_FONT_UPLOADED_MSG', "您的字體文件已上傳。");
+define('MANAGE_FONTS_FONT_UPLOAD_ERR', "試圖上傳字體時出錯。");
+define('MANAGE_FONTS_FONT_UPLOAD_CANCEL_MSG', "上傳已被用戶取消或瀏覽器斷開連接。");
+define('MANAGE_FONTS_NO_FONT_ERR', "&#39;字體&#39;不能為空。");
+define('MANAGE_FONTS_NO_UPLOAD_ERR', "如果選擇“上傳”，則必須從您的計算機中選擇要上傳的文件。");
+define('MANAGE_FONTS_NO_URL_ERR', "如果選中“網址”，則“網址”不能為空。");
+define('RUN_SQL_BACK_TO_EDIT_CSS_SELECT', "返回運行SQL");
+define('RUN_SQL_QUERY_SUCCESS_MSG', "查詢成功完成");
 ?>
\ No newline at end of file
